# AgenticAnnotationType


## Enum

* `HUMAN` (value: `'human'`)

* `CONTINUOUS_EVAL` (value: `'continuous_eval'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


